@@ -87,8 +87,8 @@ $lang['help'] = <<<EOT
  <li><code>{cgfb_like}</code> Will display a Facebook like button to allow users to &quot;Like&quot; The current Page.<br/><u>Note:</u> you should turn yoru web pages and other items into &quot;Graph Objects&quot; for optimal behaviour.</li>
  <li><code>{cgfb_comments}</code> Will display a form allowing users to add a comment to the current page, or an item on the page, and to view the comments of others.</li>
 </ul><br/>
- <p>The simplest way to add facebook integration into your site is just to add <code style="color: blue;">{cgfb_like}</code> into the page template of your site.  Now any page that uses this page template will have a facebook &quot;Like&quot; button attached to it.  You do not need to create a facebook application, or even to call {cgfb_init} to use this function.</p>
- <p>The next most common way to add facebook integration into your site is to allow visitors to enter comments.  You can do this by adding the <code style="color: blue;">{cgfb_comments}</code> tag into your page template.</p>
+ <p>The simplest way to add facebook integration into your site is just to add <code style="color: blue;">{cgfb_init}{cgfb_like}</code> into the page template of your site.  Now any page that uses this page template will have a facebook &quot;Like&quot; button attached to it.  You do not need to create a facebook application to use this function.</p>
+<p>The next most common way to add facebook integration into your site is to allow visitors to enter comments.  You can do this by adding the <code style="color: blue;">{cgfb_init}{cgfb_comments}</code> tag into your page template.</p>
  <p>Adding a &quot;like&quot; button beside each entry on your Product summary views you can simply pass the detail url value for each product displayed in the summary view as the <em>href</em> parameter to the {cgfb_like} tag.  i.e:<br/>
  <pre>{foreach from=\$items item=entry}<br/>{* your other summary template stuff *}<br/><span style="color: green;">{cgfb_like href=\$entry->detail_url}</span><br/>{/foreach}</pre>
  <p>
@@ -120,7 +120,7 @@ $lang['help'] = <<<EOT
 
 <br/><h4><u>Simple Facebook Applications:</u></h4>
 <ul>
- <li><code>{cgfb_init}</code> Will output the javascript to initialize the Facebook Javascript API</li>
+ <li><code>{cgfb_init}</code> Will output the javascript to initialize the Facebook Javascript API.</li>
  <li><code>{cgfb_login}</code> Will display a Facebook login button.</li>
  <li><code>{cgfb_logout}</code> Will display a Facebook logout button.</li>
  <li><code>{cgfb_uid}</code> Will display the users Facebook User ID.</li>
